@@ -403,7 +403,7 @@ class Symbolizer(Subcommand):
         if self.live:
             print("Entering live mode")
             self.substitute_stdin(resolver)
-            sys.exit(0)
+            return SubcommandResult.SUCCESS
 
         # Skip over everything before the first '{' since it is likely to be log line prefixes.
         # Additionally, using raw_decode() to ignore extra data after the closing '}' to allow maximal
@@ -442,7 +442,7 @@ class Symbolizer(Subcommand):
                 pass
         else:
             print("could not find json backtrace object in input", file=sys.stderr)
-            exit(1)
+            return SubcommandResult.FAIL
 
         output_fn = None
         if self.output_format == "json":
